searchData={"items":[{"type":"module","title":"ExSui","doc":"ExSui is a comprehensive Elixir library that provides a high-performance, type-safe interface for interacting with the [Sui](https://sui.io/)\nblockchain through its native [gRPC API](https://docs.sui.io/concepts/grpc-overview).\n\n[Sui](https://sui.io/) is a Layer 1 blockchain designed for near-instant, low-cost transactions with parallel processing and optimized scalability,\nmaking it ideal for DeFi, NFTs, and gaming. Sui uses [Move](https://sui.io/move), a smart contract language designed for safety and efficiency.\nUnlike traditional smart contract languages like Solidity, Move is built with security in mind, minimizing common\nvulnerabilities such as reentrancy attacks and ensuring better resource management.","ref":"ExSui.html"},{"type":"function","title":"ExSui.get_checkpoint/0","doc":"Gets the current Sui blockchain checkpoint.","ref":"ExSui.html#get_checkpoint/0"},{"type":"function","title":"Examples - ExSui.get_checkpoint/0","doc":"iex> ExSui.get_checkpoint()\n    {:ok,\n      %Sui.Rpc.V2beta.Checkpoint{\n        sequence_number: 212984592,\n        digest: \"4iuCTmYRJgVKGtZV2cN1piwgsftqFMcepo4ezRgTYoEE\",\n        summary: nil,\n        signature: nil,\n        contents: nil,\n        transactions: [],\n        __unknown_fields__: []\n      }}","ref":"ExSui.html#get_checkpoint/0-examples"},{"type":"function","title":"ExSui.get_checkpoint/1","doc":"Gets the current Sui blockchain checkpoint.","ref":"ExSui.html#get_checkpoint/1"},{"type":"function","title":"Examples - ExSui.get_checkpoint/1","doc":"iex> ExSui.get_checkpoint(%Sui.Rpc.V2beta.GetCheckpointRequest{})\n    {:ok,\n      %Sui.Rpc.V2beta.Checkpoint{\n        sequence_number: 212984592,\n        digest: \"4iuCTmYRJgVKGtZV2cN1piwgsftqFMcepo4ezRgTYoEE\",\n        summary: nil,\n        signature: nil,\n        contents: nil,\n        transactions: [],\n        __unknown_fields__: []\n      }}","ref":"ExSui.html#get_checkpoint/1-examples"},{"type":"function","title":"ExSui.get_transaction/1","doc":"Gets a transaction details.","ref":"ExSui.html#get_transaction/1"},{"type":"function","title":"Examples - ExSui.get_transaction/1","doc":"iex> transaction = %Sui.Rpc.V2beta.GetTransactionRequest{digest: \"3CadAYpBgYmgDVHWrKYne2V2bfN3ZkXfELVsBtoe7jHq\", read_mask: %{paths: [\"digest\", \"signatures\", \"events\", \"transaction\"]}}\n    iex> ExSui.get_transaction(transaction)\n    {:ok,\n      %Sui.Rpc.V2beta.ExecutedTransaction{\n        digest: \"3CadAYpBgYmgDVHWrKYne2V2bfN3ZkXfELVsBtoe7jHq\",\n        transaction: %Sui.Rpc.V2beta.Transaction{\n          bcs: %Sui.Rpc.V2beta.Bcs{\n            name: \"TransactionData\",\n            value: <<0, 0, 11, ...>>,\n            __unknown_fields__: []\n          },\n          digest: \"3CadAYpBgYmgDVHWrKYne2V2bfN3ZkXfELVsBtoe7jHq\",\n          version: 1,\n          kind: %Sui.Rpc.V2beta.TransactionKind{\n            kind: {:programmable_transaction, ...},\n            __unknown_fields__: []\n          },\n          sender: \"0xe193565230dd7147bf7a9155cfbe1f25eec0feea71553dd76e84c3557f2c72db\",\n          gas_payment: %Sui.Rpc.V2beta.GasPayment{...},\n          ...\n        },\n        signatures: [\n          %Sui.Rpc.V2beta.UserSignature{\n            bcs: %Sui.Rpc.V2beta.Bcs{\n              name: \"UserSignatureBytes\",\n              value: <<0, ...>>,\n              __unknown_fields__: []\n            },\n            scheme: :ED25519,\n            signature: <<107, ...>>,\n            public_key: <<...>>,\n            ...\n          }\n        ],\n        effects: nil,\n        events: %Sui.Rpc.V2beta.TransactionEvents{\n          bcs: %Sui.Rpc.V2beta.Bcs{name: \"TransactionEvents\", value: <<...>>, ...},\n          digest: \"6ZWN85BdqXQEogb96zMMW9YDWps9dN3N4kf1CSrGr8Gj\",\n          events: [...],\n          ...\n        },\n        checkpoint: nil,\n        timestamp: nil,\n        balance_changes: [],\n        ...\n      }}","ref":"ExSui.html#get_transaction/1-examples"},{"type":"module","title":"ExSui.Client","doc":"Sui gRPC client","ref":"ExSui.Client.html"},{"type":"function","title":"ExSui.Client.channel/0","doc":"","ref":"ExSui.Client.html#channel/0"},{"type":"function","title":"ExSui.Client.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExSui.Client.html#child_spec/1"},{"type":"function","title":"ExSui.Client.start_link/1","doc":"","ref":"ExSui.Client.html#start_link/1"},{"type":"module","title":"ExSui.Core","doc":"Contains functions to interface with the Sui Ledger service.","ref":"ExSui.Core.html"},{"type":"function","title":"ExSui.Core.get_checkpoint/1","doc":"Gets the current sui blockchain checkpoint.","ref":"ExSui.Core.html#get_checkpoint/1"},{"type":"function","title":"ExSui.Core.get_reference_gas_price/1","doc":"Gets the current sui blockchain reference gas price.","ref":"ExSui.Core.html#get_reference_gas_price/1"},{"type":"function","title":"ExSui.Core.get_transaction/1","doc":"Gets a transaction's details.","ref":"ExSui.Core.html#get_transaction/1"},{"type":"module","title":"Google.Rpc.BadRequest","doc":"Describes violations in a client request. This error type focuses on the\nsyntactic aspects of the request.","ref":"Google.Rpc.BadRequest.html"},{"type":"function","title":"Google.Rpc.BadRequest.descriptor/0","doc":"","ref":"Google.Rpc.BadRequest.html#descriptor/0"},{"type":"type","title":"Google.Rpc.BadRequest.t/0","doc":"","ref":"Google.Rpc.BadRequest.html#t:t/0"},{"type":"module","title":"Google.Rpc.BadRequest.FieldViolation","doc":"A message type used to describe a single bad request field.","ref":"Google.Rpc.BadRequest.FieldViolation.html"},{"type":"function","title":"Google.Rpc.BadRequest.FieldViolation.descriptor/0","doc":"","ref":"Google.Rpc.BadRequest.FieldViolation.html#descriptor/0"},{"type":"type","title":"Google.Rpc.BadRequest.FieldViolation.t/0","doc":"","ref":"Google.Rpc.BadRequest.FieldViolation.html#t:t/0"},{"type":"module","title":"Google.Rpc.DebugInfo","doc":"Describes additional debugging info.","ref":"Google.Rpc.DebugInfo.html"},{"type":"function","title":"Google.Rpc.DebugInfo.descriptor/0","doc":"","ref":"Google.Rpc.DebugInfo.html#descriptor/0"},{"type":"type","title":"Google.Rpc.DebugInfo.t/0","doc":"","ref":"Google.Rpc.DebugInfo.html#t:t/0"},{"type":"module","title":"Google.Rpc.ErrorInfo","doc":"Describes the cause of the error with structured details.\n\nExample of an error when contacting the \"pubsub.googleapis.com\" API when it\nis not enabled:\n\n```text,json\n{ \"reason\": \"API_DISABLED\"\n\"domain\": \"googleapis.com\"\n\"metadata\": {\n\"resource\": \"projects/123\",\n\"service\": \"pubsub.googleapis.com\"\n}\n}\n```\n\nThis response indicates that the pubsub.googleapis.com API is not enabled.\n\nExample of an error that is returned when attempting to create a Spanner\ninstance in a region that is out of stock:\n\n```text,json\n{ \"reason\": \"STOCKOUT\"\n\"domain\": \"spanner.googleapis.com\",\n\"metadata\": {\n\"availableRegions\": \"us-central1,us-east2\"\n}\n}\n```","ref":"Google.Rpc.ErrorInfo.html"},{"type":"function","title":"Google.Rpc.ErrorInfo.descriptor/0","doc":"","ref":"Google.Rpc.ErrorInfo.html#descriptor/0"},{"type":"type","title":"Google.Rpc.ErrorInfo.t/0","doc":"","ref":"Google.Rpc.ErrorInfo.html#t:t/0"},{"type":"module","title":"Google.Rpc.ErrorInfo.MetadataEntry","doc":"","ref":"Google.Rpc.ErrorInfo.MetadataEntry.html"},{"type":"function","title":"Google.Rpc.ErrorInfo.MetadataEntry.descriptor/0","doc":"","ref":"Google.Rpc.ErrorInfo.MetadataEntry.html#descriptor/0"},{"type":"type","title":"Google.Rpc.ErrorInfo.MetadataEntry.t/0","doc":"","ref":"Google.Rpc.ErrorInfo.MetadataEntry.html#t:t/0"},{"type":"module","title":"Google.Rpc.Help","doc":"Provides links to documentation or for performing an out of band action.\n\nFor example, if a quota check failed with an error indicating the calling\nproject hasn't enabled the accessed service, this can contain a URL pointing\ndirectly to the right place in the developer console to flip the bit.","ref":"Google.Rpc.Help.html"},{"type":"function","title":"Google.Rpc.Help.descriptor/0","doc":"","ref":"Google.Rpc.Help.html#descriptor/0"},{"type":"type","title":"Google.Rpc.Help.t/0","doc":"","ref":"Google.Rpc.Help.html#t:t/0"},{"type":"module","title":"Google.Rpc.Help.Link","doc":"Describes a URL link.","ref":"Google.Rpc.Help.Link.html"},{"type":"function","title":"Google.Rpc.Help.Link.descriptor/0","doc":"","ref":"Google.Rpc.Help.Link.html#descriptor/0"},{"type":"type","title":"Google.Rpc.Help.Link.t/0","doc":"","ref":"Google.Rpc.Help.Link.html#t:t/0"},{"type":"module","title":"Google.Rpc.LocalizedMessage","doc":"Provides a localized error message that is safe to return to the user\nwhich can be attached to an RPC error.","ref":"Google.Rpc.LocalizedMessage.html"},{"type":"function","title":"Google.Rpc.LocalizedMessage.descriptor/0","doc":"","ref":"Google.Rpc.LocalizedMessage.html#descriptor/0"},{"type":"type","title":"Google.Rpc.LocalizedMessage.t/0","doc":"","ref":"Google.Rpc.LocalizedMessage.html#t:t/0"},{"type":"module","title":"Google.Rpc.PreconditionFailure","doc":"Describes what preconditions have failed.\n\nFor example, if an RPC failed because it required the Terms of Service to be\nacknowledged, it could list the terms of service violation in the\nPreconditionFailure message.","ref":"Google.Rpc.PreconditionFailure.html"},{"type":"function","title":"Google.Rpc.PreconditionFailure.descriptor/0","doc":"","ref":"Google.Rpc.PreconditionFailure.html#descriptor/0"},{"type":"type","title":"Google.Rpc.PreconditionFailure.t/0","doc":"","ref":"Google.Rpc.PreconditionFailure.html#t:t/0"},{"type":"module","title":"Google.Rpc.PreconditionFailure.Violation","doc":"A message type used to describe a single precondition failure.","ref":"Google.Rpc.PreconditionFailure.Violation.html"},{"type":"function","title":"Google.Rpc.PreconditionFailure.Violation.descriptor/0","doc":"","ref":"Google.Rpc.PreconditionFailure.Violation.html#descriptor/0"},{"type":"type","title":"Google.Rpc.PreconditionFailure.Violation.t/0","doc":"","ref":"Google.Rpc.PreconditionFailure.Violation.html#t:t/0"},{"type":"module","title":"Google.Rpc.QuotaFailure","doc":"Describes how a quota check failed.\n\nFor example if a daily limit was exceeded for the calling project,\na service could respond with a QuotaFailure detail containing the project\nid and the description of the quota limit that was exceeded.  If the\ncalling project hasn't enabled the service in the developer console, then\na service could respond with the project id and set `service_disabled`\nto true.\n\nAlso see RetryInfo and Help types for other details about handling a\nquota failure.","ref":"Google.Rpc.QuotaFailure.html"},{"type":"function","title":"Google.Rpc.QuotaFailure.descriptor/0","doc":"","ref":"Google.Rpc.QuotaFailure.html#descriptor/0"},{"type":"type","title":"Google.Rpc.QuotaFailure.t/0","doc":"","ref":"Google.Rpc.QuotaFailure.html#t:t/0"},{"type":"module","title":"Google.Rpc.QuotaFailure.Violation","doc":"A message type used to describe a single quota violation.  For example, a\ndaily quota or a custom quota that was exceeded.","ref":"Google.Rpc.QuotaFailure.Violation.html"},{"type":"function","title":"Google.Rpc.QuotaFailure.Violation.descriptor/0","doc":"","ref":"Google.Rpc.QuotaFailure.Violation.html#descriptor/0"},{"type":"type","title":"Google.Rpc.QuotaFailure.Violation.t/0","doc":"","ref":"Google.Rpc.QuotaFailure.Violation.html#t:t/0"},{"type":"module","title":"Google.Rpc.RequestInfo","doc":"Contains metadata about the request that clients can attach when filing a bug\nor providing other forms of feedback.","ref":"Google.Rpc.RequestInfo.html"},{"type":"function","title":"Google.Rpc.RequestInfo.descriptor/0","doc":"","ref":"Google.Rpc.RequestInfo.html#descriptor/0"},{"type":"type","title":"Google.Rpc.RequestInfo.t/0","doc":"","ref":"Google.Rpc.RequestInfo.html#t:t/0"},{"type":"module","title":"Google.Rpc.ResourceInfo","doc":"Describes the resource that is being accessed.","ref":"Google.Rpc.ResourceInfo.html"},{"type":"function","title":"Google.Rpc.ResourceInfo.descriptor/0","doc":"","ref":"Google.Rpc.ResourceInfo.html#descriptor/0"},{"type":"type","title":"Google.Rpc.ResourceInfo.t/0","doc":"","ref":"Google.Rpc.ResourceInfo.html#t:t/0"},{"type":"module","title":"Google.Rpc.RetryInfo","doc":"Describes when the clients can retry a failed request. Clients could ignore\nthe recommendation here or retry when this information is missing from error\nresponses.\n\nIt's always recommended that clients should use exponential backoff when\nretrying.\n\nClients should wait until `retry_delay` amount of time has passed since\nreceiving the error response before retrying.  If retrying requests also\nfail, clients should use an exponential backoff scheme to gradually increase\nthe delay between retries based on `retry_delay`, until either a maximum\nnumber of retries have been reached or a maximum retry delay cap has been\nreached.","ref":"Google.Rpc.RetryInfo.html"},{"type":"function","title":"Google.Rpc.RetryInfo.descriptor/0","doc":"","ref":"Google.Rpc.RetryInfo.html#descriptor/0"},{"type":"type","title":"Google.Rpc.RetryInfo.t/0","doc":"","ref":"Google.Rpc.RetryInfo.html#t:t/0"},{"type":"module","title":"Google.Rpc.Status","doc":"The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors).","ref":"Google.Rpc.Status.html"},{"type":"function","title":"Google.Rpc.Status.descriptor/0","doc":"","ref":"Google.Rpc.Status.html#descriptor/0"},{"type":"type","title":"Google.Rpc.Status.t/0","doc":"","ref":"Google.Rpc.Status.html#t:t/0"},{"type":"task","title":"mix ex_sui.install_sui_grpc_protos","doc":"Clones the sui gRPC protobuf files from their github repository","ref":"Mix.Tasks.ExSui.InstallSuiGrpcProtos.html"},{"type":"function","title":"Mix.Tasks.ExSui.InstallSuiGrpcProtos.run/1","doc":"Callback implementation for  Mix.Task.run/1 .","ref":"Mix.Tasks.ExSui.InstallSuiGrpcProtos.html#run/1"},{"type":"module","title":"Sui.Rpc.V2alpha.Ability","doc":"An `Ability` classifies what operations are permitted for a given type","ref":"Sui.Rpc.V2alpha.Ability.html"},{"type":"function","title":"Sui.Rpc.V2alpha.Ability.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.Ability.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.Ability.t/0","doc":"","ref":"Sui.Rpc.V2alpha.Ability.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.AbilitySet","doc":"A set of abilities for a type parameter","ref":"Sui.Rpc.V2alpha.AbilitySet.html"},{"type":"function","title":"Sui.Rpc.V2alpha.AbilitySet.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.AbilitySet.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.AbilitySet.t/0","doc":"","ref":"Sui.Rpc.V2alpha.AbilitySet.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.Balance","doc":"Balance information for a specific coin type.","ref":"Sui.Rpc.V2alpha.Balance.html"},{"type":"function","title":"Sui.Rpc.V2alpha.Balance.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.Balance.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.Balance.t/0","doc":"","ref":"Sui.Rpc.V2alpha.Balance.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.CoinMetadata","doc":"Metadata for a coin type","ref":"Sui.Rpc.V2alpha.CoinMetadata.html"},{"type":"function","title":"Sui.Rpc.V2alpha.CoinMetadata.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.CoinMetadata.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.CoinMetadata.t/0","doc":"","ref":"Sui.Rpc.V2alpha.CoinMetadata.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.CoinTreasury","doc":"Information about a coin type's `0x2::coin::TreasuryCap` and its total available supply","ref":"Sui.Rpc.V2alpha.CoinTreasury.html"},{"type":"function","title":"Sui.Rpc.V2alpha.CoinTreasury.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.CoinTreasury.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.CoinTreasury.t/0","doc":"","ref":"Sui.Rpc.V2alpha.CoinTreasury.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.CommandOutput","doc":"","ref":"Sui.Rpc.V2alpha.CommandOutput.html"},{"type":"function","title":"Sui.Rpc.V2alpha.CommandOutput.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.CommandOutput.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.CommandOutput.t/0","doc":"","ref":"Sui.Rpc.V2alpha.CommandOutput.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.CommandResult","doc":"An intermediate result/output from the execution of a single command","ref":"Sui.Rpc.V2alpha.CommandResult.html"},{"type":"function","title":"Sui.Rpc.V2alpha.CommandResult.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.CommandResult.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.CommandResult.t/0","doc":"","ref":"Sui.Rpc.V2alpha.CommandResult.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.DatatypeDescriptor","doc":"Describes a Move Datatype.","ref":"Sui.Rpc.V2alpha.DatatypeDescriptor.html"},{"type":"function","title":"Sui.Rpc.V2alpha.DatatypeDescriptor.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.DatatypeDescriptor.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.DatatypeDescriptor.t/0","doc":"","ref":"Sui.Rpc.V2alpha.DatatypeDescriptor.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.DatatypeDescriptor.DatatypeKind","doc":"","ref":"Sui.Rpc.V2alpha.DatatypeDescriptor.DatatypeKind.html"},{"type":"function","title":"Sui.Rpc.V2alpha.DatatypeDescriptor.DatatypeKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.DatatypeDescriptor.DatatypeKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.DatatypeDescriptor.DatatypeKind.t/0","doc":"","ref":"Sui.Rpc.V2alpha.DatatypeDescriptor.DatatypeKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.DynamicField","doc":"","ref":"Sui.Rpc.V2alpha.DynamicField.html"},{"type":"function","title":"Sui.Rpc.V2alpha.DynamicField.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.DynamicField.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.DynamicField.t/0","doc":"","ref":"Sui.Rpc.V2alpha.DynamicField.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.DynamicField.DynamicFieldKind","doc":"","ref":"Sui.Rpc.V2alpha.DynamicField.DynamicFieldKind.html"},{"type":"function","title":"Sui.Rpc.V2alpha.DynamicField.DynamicFieldKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.DynamicField.DynamicFieldKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.DynamicField.DynamicFieldKind.t/0","doc":"","ref":"Sui.Rpc.V2alpha.DynamicField.DynamicFieldKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.FieldDescriptor","doc":"Descriptor of a field that belongs to a struct or enum variant","ref":"Sui.Rpc.V2alpha.FieldDescriptor.html"},{"type":"function","title":"Sui.Rpc.V2alpha.FieldDescriptor.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.FieldDescriptor.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.FieldDescriptor.t/0","doc":"","ref":"Sui.Rpc.V2alpha.FieldDescriptor.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.FunctionDescriptor","doc":"Descriptor of a Move function","ref":"Sui.Rpc.V2alpha.FunctionDescriptor.html"},{"type":"function","title":"Sui.Rpc.V2alpha.FunctionDescriptor.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.FunctionDescriptor.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.FunctionDescriptor.t/0","doc":"","ref":"Sui.Rpc.V2alpha.FunctionDescriptor.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.FunctionDescriptor.Visibility","doc":"","ref":"Sui.Rpc.V2alpha.FunctionDescriptor.Visibility.html"},{"type":"function","title":"Sui.Rpc.V2alpha.FunctionDescriptor.Visibility.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.FunctionDescriptor.Visibility.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.FunctionDescriptor.Visibility.t/0","doc":"","ref":"Sui.Rpc.V2alpha.FunctionDescriptor.Visibility.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetBalanceRequest","doc":"Request message for `LiveDataService.GetBalance`.","ref":"Sui.Rpc.V2alpha.GetBalanceRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetBalanceRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetBalanceRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetBalanceRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetBalanceRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetBalanceResponse","doc":"Response message for `LiveDataService.GetBalance`.\nReturn the total coin balance for one coin type, owned by the address owner.","ref":"Sui.Rpc.V2alpha.GetBalanceResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetBalanceResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetBalanceResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetBalanceResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetBalanceResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetCoinInfoRequest","doc":"Request message for `NodeService.GetCoinInfo`.","ref":"Sui.Rpc.V2alpha.GetCoinInfoRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetCoinInfoRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetCoinInfoRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetCoinInfoRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetCoinInfoRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetCoinInfoResponse","doc":"Response message for `NodeService.GetCoinInfo`.","ref":"Sui.Rpc.V2alpha.GetCoinInfoResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetCoinInfoResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetCoinInfoResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetCoinInfoResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetCoinInfoResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetDatatypeRequest","doc":"","ref":"Sui.Rpc.V2alpha.GetDatatypeRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetDatatypeRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetDatatypeRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetDatatypeRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetDatatypeRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetDatatypeResponse","doc":"","ref":"Sui.Rpc.V2alpha.GetDatatypeResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetDatatypeResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetDatatypeResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetDatatypeResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetDatatypeResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetFunctionRequest","doc":"","ref":"Sui.Rpc.V2alpha.GetFunctionRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetFunctionRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetFunctionRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetFunctionRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetFunctionRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetFunctionResponse","doc":"","ref":"Sui.Rpc.V2alpha.GetFunctionResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetFunctionResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetFunctionResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetFunctionResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetFunctionResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetModuleRequest","doc":"","ref":"Sui.Rpc.V2alpha.GetModuleRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetModuleRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetModuleRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetModuleRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetModuleRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetModuleResponse","doc":"","ref":"Sui.Rpc.V2alpha.GetModuleResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetModuleResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetModuleResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetModuleResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetModuleResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetPackageRequest","doc":"","ref":"Sui.Rpc.V2alpha.GetPackageRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetPackageRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetPackageRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetPackageRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetPackageRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.GetPackageResponse","doc":"","ref":"Sui.Rpc.V2alpha.GetPackageResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.GetPackageResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.GetPackageResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.GetPackageResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.GetPackageResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.ListBalancesRequest","doc":"Request message for `LiveDataService.ListBalances`.","ref":"Sui.Rpc.V2alpha.ListBalancesRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.ListBalancesRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.ListBalancesRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.ListBalancesRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.ListBalancesRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.ListBalancesResponse","doc":"Response message for `LiveDataService.ListBalances`.\nReturn the total coin balance for all coin types, owned by the address owner.","ref":"Sui.Rpc.V2alpha.ListBalancesResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.ListBalancesResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.ListBalancesResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.ListBalancesResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.ListBalancesResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.ListDynamicFieldsRequest","doc":"Request message for `NodeService.ListDynamicFields`","ref":"Sui.Rpc.V2alpha.ListDynamicFieldsRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.ListDynamicFieldsRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.ListDynamicFieldsRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.ListDynamicFieldsRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.ListDynamicFieldsRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.ListDynamicFieldsResponse","doc":"Response message for `NodeService.ListDynamicFields`","ref":"Sui.Rpc.V2alpha.ListDynamicFieldsResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.ListDynamicFieldsResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.ListDynamicFieldsResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.ListDynamicFieldsResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.ListDynamicFieldsResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.ListOwnedObjectsRequest","doc":"","ref":"Sui.Rpc.V2alpha.ListOwnedObjectsRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.ListOwnedObjectsRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.ListOwnedObjectsRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.ListOwnedObjectsRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.ListOwnedObjectsRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.ListOwnedObjectsResponse","doc":"","ref":"Sui.Rpc.V2alpha.ListOwnedObjectsResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.ListOwnedObjectsResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.ListOwnedObjectsResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.ListOwnedObjectsResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.ListOwnedObjectsResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.ListPackageVersionsRequest","doc":"","ref":"Sui.Rpc.V2alpha.ListPackageVersionsRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.ListPackageVersionsRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.ListPackageVersionsRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.ListPackageVersionsRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.ListPackageVersionsRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.ListPackageVersionsResponse","doc":"","ref":"Sui.Rpc.V2alpha.ListPackageVersionsResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.ListPackageVersionsResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.ListPackageVersionsResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.ListPackageVersionsResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.ListPackageVersionsResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.LiveDataService.Service","doc":"","ref":"Sui.Rpc.V2alpha.LiveDataService.Service.html"},{"type":"function","title":"Sui.Rpc.V2alpha.LiveDataService.Service.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.LiveDataService.Service.html#descriptor/0"},{"type":"module","title":"Sui.Rpc.V2alpha.LiveDataService.Stub","doc":"","ref":"Sui.Rpc.V2alpha.LiveDataService.Stub.html"},{"type":"function","title":"Sui.Rpc.V2alpha.LiveDataService.Stub.get_balance/3","doc":"","ref":"Sui.Rpc.V2alpha.LiveDataService.Stub.html#get_balance/3"},{"type":"function","title":"Sui.Rpc.V2alpha.LiveDataService.Stub.get_coin_info/3","doc":"","ref":"Sui.Rpc.V2alpha.LiveDataService.Stub.html#get_coin_info/3"},{"type":"function","title":"Sui.Rpc.V2alpha.LiveDataService.Stub.list_balances/3","doc":"","ref":"Sui.Rpc.V2alpha.LiveDataService.Stub.html#list_balances/3"},{"type":"function","title":"Sui.Rpc.V2alpha.LiveDataService.Stub.list_dynamic_fields/3","doc":"","ref":"Sui.Rpc.V2alpha.LiveDataService.Stub.html#list_dynamic_fields/3"},{"type":"function","title":"Sui.Rpc.V2alpha.LiveDataService.Stub.list_owned_objects/3","doc":"","ref":"Sui.Rpc.V2alpha.LiveDataService.Stub.html#list_owned_objects/3"},{"type":"function","title":"Sui.Rpc.V2alpha.LiveDataService.Stub.simulate_transaction/3","doc":"","ref":"Sui.Rpc.V2alpha.LiveDataService.Stub.html#simulate_transaction/3"},{"type":"module","title":"Sui.Rpc.V2alpha.Module","doc":"A Move Module.","ref":"Sui.Rpc.V2alpha.Module.html"},{"type":"function","title":"Sui.Rpc.V2alpha.Module.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.Module.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.Module.t/0","doc":"","ref":"Sui.Rpc.V2alpha.Module.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.MovePackageService.Service","doc":"","ref":"Sui.Rpc.V2alpha.MovePackageService.Service.html"},{"type":"function","title":"Sui.Rpc.V2alpha.MovePackageService.Service.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.MovePackageService.Service.html#descriptor/0"},{"type":"module","title":"Sui.Rpc.V2alpha.MovePackageService.Stub","doc":"","ref":"Sui.Rpc.V2alpha.MovePackageService.Stub.html"},{"type":"function","title":"Sui.Rpc.V2alpha.MovePackageService.Stub.get_datatype/3","doc":"","ref":"Sui.Rpc.V2alpha.MovePackageService.Stub.html#get_datatype/3"},{"type":"function","title":"Sui.Rpc.V2alpha.MovePackageService.Stub.get_function/3","doc":"","ref":"Sui.Rpc.V2alpha.MovePackageService.Stub.html#get_function/3"},{"type":"function","title":"Sui.Rpc.V2alpha.MovePackageService.Stub.get_module/3","doc":"","ref":"Sui.Rpc.V2alpha.MovePackageService.Stub.html#get_module/3"},{"type":"function","title":"Sui.Rpc.V2alpha.MovePackageService.Stub.get_package/3","doc":"","ref":"Sui.Rpc.V2alpha.MovePackageService.Stub.html#get_package/3"},{"type":"function","title":"Sui.Rpc.V2alpha.MovePackageService.Stub.list_package_versions/3","doc":"","ref":"Sui.Rpc.V2alpha.MovePackageService.Stub.html#list_package_versions/3"},{"type":"module","title":"Sui.Rpc.V2alpha.OpenSignature","doc":"Representation of a type signature that could appear as a function parameter or return value.","ref":"Sui.Rpc.V2alpha.OpenSignature.html"},{"type":"function","title":"Sui.Rpc.V2alpha.OpenSignature.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignature.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.OpenSignature.t/0","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignature.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.OpenSignature.Reference","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignature.Reference.html"},{"type":"function","title":"Sui.Rpc.V2alpha.OpenSignature.Reference.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignature.Reference.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.OpenSignature.Reference.t/0","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignature.Reference.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.OpenSignatureBody","doc":"Representation of a type signature that could appear as a field type for a struct or enum","ref":"Sui.Rpc.V2alpha.OpenSignatureBody.html"},{"type":"function","title":"Sui.Rpc.V2alpha.OpenSignatureBody.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignatureBody.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.OpenSignatureBody.t/0","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignatureBody.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.OpenSignatureBody.Type","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignatureBody.Type.html"},{"type":"function","title":"Sui.Rpc.V2alpha.OpenSignatureBody.Type.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignatureBody.Type.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.OpenSignatureBody.Type.t/0","doc":"","ref":"Sui.Rpc.V2alpha.OpenSignatureBody.Type.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.OwnedObject","doc":"","ref":"Sui.Rpc.V2alpha.OwnedObject.html"},{"type":"function","title":"Sui.Rpc.V2alpha.OwnedObject.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.OwnedObject.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.OwnedObject.t/0","doc":"","ref":"Sui.Rpc.V2alpha.OwnedObject.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.Package","doc":"A Move Package","ref":"Sui.Rpc.V2alpha.Package.html"},{"type":"function","title":"Sui.Rpc.V2alpha.Package.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.Package.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.Package.t/0","doc":"","ref":"Sui.Rpc.V2alpha.Package.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.PackageVersion","doc":"A simplified representation of a package version","ref":"Sui.Rpc.V2alpha.PackageVersion.html"},{"type":"function","title":"Sui.Rpc.V2alpha.PackageVersion.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.PackageVersion.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.PackageVersion.t/0","doc":"","ref":"Sui.Rpc.V2alpha.PackageVersion.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.RegulatedCoinMetadata","doc":"Information about a regulated coin, which indicates that it makes use of the transfer deny list.","ref":"Sui.Rpc.V2alpha.RegulatedCoinMetadata.html"},{"type":"function","title":"Sui.Rpc.V2alpha.RegulatedCoinMetadata.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.RegulatedCoinMetadata.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.RegulatedCoinMetadata.t/0","doc":"","ref":"Sui.Rpc.V2alpha.RegulatedCoinMetadata.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.SignatureVerificationService.Service","doc":"","ref":"Sui.Rpc.V2alpha.SignatureVerificationService.Service.html"},{"type":"function","title":"Sui.Rpc.V2alpha.SignatureVerificationService.Service.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.SignatureVerificationService.Service.html#descriptor/0"},{"type":"module","title":"Sui.Rpc.V2alpha.SignatureVerificationService.Stub","doc":"","ref":"Sui.Rpc.V2alpha.SignatureVerificationService.Stub.html"},{"type":"function","title":"Sui.Rpc.V2alpha.SignatureVerificationService.Stub.verify_signature/3","doc":"","ref":"Sui.Rpc.V2alpha.SignatureVerificationService.Stub.html#verify_signature/3"},{"type":"module","title":"Sui.Rpc.V2alpha.SimulateTransactionRequest","doc":"","ref":"Sui.Rpc.V2alpha.SimulateTransactionRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.SimulateTransactionRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.SimulateTransactionRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.SimulateTransactionRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.SimulateTransactionRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.SimulateTransactionRequest.VmChecks","doc":"buf:lint:ignore ENUM_ZERO_VALUE_SUFFIX","ref":"Sui.Rpc.V2alpha.SimulateTransactionRequest.VmChecks.html"},{"type":"function","title":"Sui.Rpc.V2alpha.SimulateTransactionRequest.VmChecks.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.SimulateTransactionRequest.VmChecks.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.SimulateTransactionRequest.VmChecks.t/0","doc":"","ref":"Sui.Rpc.V2alpha.SimulateTransactionRequest.VmChecks.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.SimulateTransactionResponse","doc":"","ref":"Sui.Rpc.V2alpha.SimulateTransactionResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.SimulateTransactionResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.SimulateTransactionResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.SimulateTransactionResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.SimulateTransactionResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.SubscribeCheckpointsRequest","doc":"Request message for SubscriptionService.SubscribeCheckpoints","ref":"Sui.Rpc.V2alpha.SubscribeCheckpointsRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.SubscribeCheckpointsRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.SubscribeCheckpointsRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.SubscribeCheckpointsRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.SubscribeCheckpointsRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.SubscribeCheckpointsResponse","doc":"Response message for SubscriptionService.SubscribeCheckpoints","ref":"Sui.Rpc.V2alpha.SubscribeCheckpointsResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.SubscribeCheckpointsResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.SubscribeCheckpointsResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.SubscribeCheckpointsResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.SubscribeCheckpointsResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.SubscriptionService.Service","doc":"","ref":"Sui.Rpc.V2alpha.SubscriptionService.Service.html"},{"type":"function","title":"Sui.Rpc.V2alpha.SubscriptionService.Service.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.SubscriptionService.Service.html#descriptor/0"},{"type":"module","title":"Sui.Rpc.V2alpha.SubscriptionService.Stub","doc":"","ref":"Sui.Rpc.V2alpha.SubscriptionService.Stub.html"},{"type":"function","title":"Sui.Rpc.V2alpha.SubscriptionService.Stub.subscribe_checkpoints/3","doc":"","ref":"Sui.Rpc.V2alpha.SubscriptionService.Stub.html#subscribe_checkpoints/3"},{"type":"module","title":"Sui.Rpc.V2alpha.TypeParameter","doc":"A generic type parameter used in the declaration of a struct or enum.","ref":"Sui.Rpc.V2alpha.TypeParameter.html"},{"type":"function","title":"Sui.Rpc.V2alpha.TypeParameter.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.TypeParameter.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.TypeParameter.t/0","doc":"","ref":"Sui.Rpc.V2alpha.TypeParameter.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.VariantDescriptor","doc":"Descriptor of an enum variant","ref":"Sui.Rpc.V2alpha.VariantDescriptor.html"},{"type":"function","title":"Sui.Rpc.V2alpha.VariantDescriptor.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.VariantDescriptor.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.VariantDescriptor.t/0","doc":"","ref":"Sui.Rpc.V2alpha.VariantDescriptor.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.VerifySignatureRequest","doc":"","ref":"Sui.Rpc.V2alpha.VerifySignatureRequest.html"},{"type":"function","title":"Sui.Rpc.V2alpha.VerifySignatureRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.VerifySignatureRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.VerifySignatureRequest.t/0","doc":"","ref":"Sui.Rpc.V2alpha.VerifySignatureRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2alpha.VerifySignatureResponse","doc":"","ref":"Sui.Rpc.V2alpha.VerifySignatureResponse.html"},{"type":"function","title":"Sui.Rpc.V2alpha.VerifySignatureResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2alpha.VerifySignatureResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2alpha.VerifySignatureResponse.t/0","doc":"","ref":"Sui.Rpc.V2alpha.VerifySignatureResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ActiveJwk","doc":"A new JWK.","ref":"Sui.Rpc.V2beta.ActiveJwk.html"},{"type":"function","title":"Sui.Rpc.V2beta.ActiveJwk.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ActiveJwk.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ActiveJwk.t/0","doc":"","ref":"Sui.Rpc.V2beta.ActiveJwk.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Argument","doc":"An argument to a programmable transaction command.","ref":"Sui.Rpc.V2beta.Argument.html"},{"type":"function","title":"Sui.Rpc.V2beta.Argument.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Argument.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Argument.t/0","doc":"","ref":"Sui.Rpc.V2beta.Argument.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Argument.ArgumentKind","doc":"","ref":"Sui.Rpc.V2beta.Argument.ArgumentKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.Argument.ArgumentKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Argument.ArgumentKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Argument.ArgumentKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.Argument.ArgumentKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.AuthenticatorStateExpire","doc":"Expire old JWKs.","ref":"Sui.Rpc.V2beta.AuthenticatorStateExpire.html"},{"type":"function","title":"Sui.Rpc.V2beta.AuthenticatorStateExpire.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.AuthenticatorStateExpire.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.AuthenticatorStateExpire.t/0","doc":"","ref":"Sui.Rpc.V2beta.AuthenticatorStateExpire.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.AuthenticatorStateUpdate","doc":"Update the set of valid JWKs.","ref":"Sui.Rpc.V2beta.AuthenticatorStateUpdate.html"},{"type":"function","title":"Sui.Rpc.V2beta.AuthenticatorStateUpdate.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.AuthenticatorStateUpdate.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.AuthenticatorStateUpdate.t/0","doc":"","ref":"Sui.Rpc.V2beta.AuthenticatorStateUpdate.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.BalanceChange","doc":"The delta, or change, in balance for an address for a particular `Coin` type.","ref":"Sui.Rpc.V2beta.BalanceChange.html"},{"type":"function","title":"Sui.Rpc.V2beta.BalanceChange.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.BalanceChange.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.BalanceChange.t/0","doc":"","ref":"Sui.Rpc.V2beta.BalanceChange.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.BatchGetObjectsRequest","doc":"","ref":"Sui.Rpc.V2beta.BatchGetObjectsRequest.html"},{"type":"function","title":"Sui.Rpc.V2beta.BatchGetObjectsRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.BatchGetObjectsRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.BatchGetObjectsRequest.t/0","doc":"","ref":"Sui.Rpc.V2beta.BatchGetObjectsRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.BatchGetObjectsResponse","doc":"","ref":"Sui.Rpc.V2beta.BatchGetObjectsResponse.html"},{"type":"function","title":"Sui.Rpc.V2beta.BatchGetObjectsResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.BatchGetObjectsResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.BatchGetObjectsResponse.t/0","doc":"","ref":"Sui.Rpc.V2beta.BatchGetObjectsResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.BatchGetTransactionsRequest","doc":"","ref":"Sui.Rpc.V2beta.BatchGetTransactionsRequest.html"},{"type":"function","title":"Sui.Rpc.V2beta.BatchGetTransactionsRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.BatchGetTransactionsRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.BatchGetTransactionsRequest.t/0","doc":"","ref":"Sui.Rpc.V2beta.BatchGetTransactionsRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.BatchGetTransactionsResponse","doc":"","ref":"Sui.Rpc.V2beta.BatchGetTransactionsResponse.html"},{"type":"function","title":"Sui.Rpc.V2beta.BatchGetTransactionsResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.BatchGetTransactionsResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.BatchGetTransactionsResponse.t/0","doc":"","ref":"Sui.Rpc.V2beta.BatchGetTransactionsResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Bcs","doc":"`Bcs` contains an arbitrary type that is serialized using the\n[BCS](https://mystenlabs.github.io/sui-rust-sdk/sui_sdk_types/index.html#bcs)\nformat as well as a name that identifies the type of the serialized value.","ref":"Sui.Rpc.V2beta.Bcs.html"},{"type":"function","title":"Sui.Rpc.V2beta.Bcs.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Bcs.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Bcs.t/0","doc":"","ref":"Sui.Rpc.V2beta.Bcs.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CanceledTransaction","doc":"A transaction that was canceled.","ref":"Sui.Rpc.V2beta.CanceledTransaction.html"},{"type":"function","title":"Sui.Rpc.V2beta.CanceledTransaction.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CanceledTransaction.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CanceledTransaction.t/0","doc":"","ref":"Sui.Rpc.V2beta.CanceledTransaction.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ChangeEpoch","doc":"System transaction used to change the epoch.","ref":"Sui.Rpc.V2beta.ChangeEpoch.html"},{"type":"function","title":"Sui.Rpc.V2beta.ChangeEpoch.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ChangeEpoch.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ChangeEpoch.t/0","doc":"","ref":"Sui.Rpc.V2beta.ChangeEpoch.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ChangedObject","doc":"Input/output state of an object that was changed during execution.","ref":"Sui.Rpc.V2beta.ChangedObject.html"},{"type":"function","title":"Sui.Rpc.V2beta.ChangedObject.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ChangedObject.t/0","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ChangedObject.IdOperation","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.IdOperation.html"},{"type":"function","title":"Sui.Rpc.V2beta.ChangedObject.IdOperation.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.IdOperation.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ChangedObject.IdOperation.t/0","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.IdOperation.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ChangedObject.InputObjectState","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.InputObjectState.html"},{"type":"function","title":"Sui.Rpc.V2beta.ChangedObject.InputObjectState.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.InputObjectState.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ChangedObject.InputObjectState.t/0","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.InputObjectState.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ChangedObject.OutputObjectState","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.OutputObjectState.html"},{"type":"function","title":"Sui.Rpc.V2beta.ChangedObject.OutputObjectState.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.OutputObjectState.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ChangedObject.OutputObjectState.t/0","doc":"","ref":"Sui.Rpc.V2beta.ChangedObject.OutputObjectState.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Checkpoint","doc":"","ref":"Sui.Rpc.V2beta.Checkpoint.html"},{"type":"function","title":"Sui.Rpc.V2beta.Checkpoint.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Checkpoint.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Checkpoint.t/0","doc":"","ref":"Sui.Rpc.V2beta.Checkpoint.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CheckpointCommitment","doc":"A commitment made by a checkpoint.","ref":"Sui.Rpc.V2beta.CheckpointCommitment.html"},{"type":"function","title":"Sui.Rpc.V2beta.CheckpointCommitment.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointCommitment.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CheckpointCommitment.t/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointCommitment.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CheckpointCommitment.CheckpointCommitmentKind","doc":"","ref":"Sui.Rpc.V2beta.CheckpointCommitment.CheckpointCommitmentKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.CheckpointCommitment.CheckpointCommitmentKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointCommitment.CheckpointCommitmentKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CheckpointCommitment.CheckpointCommitmentKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointCommitment.CheckpointCommitmentKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CheckpointContents","doc":"The committed to contents of a checkpoint.","ref":"Sui.Rpc.V2beta.CheckpointContents.html"},{"type":"function","title":"Sui.Rpc.V2beta.CheckpointContents.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointContents.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CheckpointContents.t/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointContents.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CheckpointSummary","doc":"A header for a checkpoint on the Sui blockchain.\n\nOn the Sui network, checkpoints define the history of the blockchain. They are quite similar to\nthe concept of blocks used by other blockchains like Bitcoin or Ethereum. The Sui blockchain,\nhowever, forms checkpoints after transaction execution has already happened to provide a\ncertified history of the chain, instead of being formed before execution.\n\nCheckpoints commit to a variety of state, including but not limited to:\n- The hash of the previous checkpoint.\n- The set of transaction digests, their corresponding effects digests, as well as the set of\nuser signatures that authorized its execution.\n- The objects produced by a transaction.\n- The set of live objects that make up the current state of the chain.\n- On epoch transitions, the next validator committee.\n\n`CheckpointSummary`s themselves don't directly include all of the previous information but they\nare the top-level type by which all the information is committed to transitively via cryptographic\nhashes included in the summary. `CheckpointSummary`s are signed and certified by a quorum of\nthe validator committee in a given epoch to allow verification of the chain's state.","ref":"Sui.Rpc.V2beta.CheckpointSummary.html"},{"type":"function","title":"Sui.Rpc.V2beta.CheckpointSummary.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointSummary.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CheckpointSummary.t/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointSummary.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CheckpointedTransactionInfo","doc":"Transaction information committed to in a checkpoint.","ref":"Sui.Rpc.V2beta.CheckpointedTransactionInfo.html"},{"type":"function","title":"Sui.Rpc.V2beta.CheckpointedTransactionInfo.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointedTransactionInfo.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CheckpointedTransactionInfo.t/0","doc":"","ref":"Sui.Rpc.V2beta.CheckpointedTransactionInfo.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CircomG1","doc":"A G1 point.","ref":"Sui.Rpc.V2beta.CircomG1.html"},{"type":"function","title":"Sui.Rpc.V2beta.CircomG1.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CircomG1.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CircomG1.t/0","doc":"","ref":"Sui.Rpc.V2beta.CircomG1.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CircomG2","doc":"A G2 point.","ref":"Sui.Rpc.V2beta.CircomG2.html"},{"type":"function","title":"Sui.Rpc.V2beta.CircomG2.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CircomG2.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CircomG2.t/0","doc":"","ref":"Sui.Rpc.V2beta.CircomG2.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Command","doc":"A single command in a programmable transaction.","ref":"Sui.Rpc.V2beta.Command.html"},{"type":"function","title":"Sui.Rpc.V2beta.Command.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Command.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Command.t/0","doc":"","ref":"Sui.Rpc.V2beta.Command.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CommandArgumentError","doc":"An error with an argument to a command.","ref":"Sui.Rpc.V2beta.CommandArgumentError.html"},{"type":"function","title":"Sui.Rpc.V2beta.CommandArgumentError.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CommandArgumentError.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CommandArgumentError.t/0","doc":"","ref":"Sui.Rpc.V2beta.CommandArgumentError.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.CommandArgumentError.CommandArgumentErrorKind","doc":"","ref":"Sui.Rpc.V2beta.CommandArgumentError.CommandArgumentErrorKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.CommandArgumentError.CommandArgumentErrorKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.CommandArgumentError.CommandArgumentErrorKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.CommandArgumentError.CommandArgumentErrorKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.CommandArgumentError.CommandArgumentErrorKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ConsensusCommitPrologue","doc":"Consensus commit prologue system transaction.\n\nThis message can represent V1, V2, and V3 prologue types.","ref":"Sui.Rpc.V2beta.ConsensusCommitPrologue.html"},{"type":"function","title":"Sui.Rpc.V2beta.ConsensusCommitPrologue.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ConsensusCommitPrologue.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ConsensusCommitPrologue.t/0","doc":"","ref":"Sui.Rpc.V2beta.ConsensusCommitPrologue.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ConsensusDeterminedVersionAssignments","doc":"Version assignments performed by consensus.","ref":"Sui.Rpc.V2beta.ConsensusDeterminedVersionAssignments.html"},{"type":"function","title":"Sui.Rpc.V2beta.ConsensusDeterminedVersionAssignments.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ConsensusDeterminedVersionAssignments.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ConsensusDeterminedVersionAssignments.t/0","doc":"","ref":"Sui.Rpc.V2beta.ConsensusDeterminedVersionAssignments.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.EndOfEpochData","doc":"Data, which when included in a `CheckpointSummary`, signals the end of an `Epoch`.","ref":"Sui.Rpc.V2beta.EndOfEpochData.html"},{"type":"function","title":"Sui.Rpc.V2beta.EndOfEpochData.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.EndOfEpochData.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.EndOfEpochData.t/0","doc":"","ref":"Sui.Rpc.V2beta.EndOfEpochData.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.EndOfEpochTransaction","doc":"Set of operations run at the end of the epoch to close out the current epoch\nand start the next one.","ref":"Sui.Rpc.V2beta.EndOfEpochTransaction.html"},{"type":"function","title":"Sui.Rpc.V2beta.EndOfEpochTransaction.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.EndOfEpochTransaction.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.EndOfEpochTransaction.t/0","doc":"","ref":"Sui.Rpc.V2beta.EndOfEpochTransaction.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.EndOfEpochTransactionKind","doc":"Operation run at the end of an epoch.","ref":"Sui.Rpc.V2beta.EndOfEpochTransactionKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.EndOfEpochTransactionKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.EndOfEpochTransactionKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.EndOfEpochTransactionKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.EndOfEpochTransactionKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Epoch","doc":"","ref":"Sui.Rpc.V2beta.Epoch.html"},{"type":"function","title":"Sui.Rpc.V2beta.Epoch.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Epoch.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Epoch.t/0","doc":"","ref":"Sui.Rpc.V2beta.Epoch.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Event","doc":"An event.","ref":"Sui.Rpc.V2beta.Event.html"},{"type":"function","title":"Sui.Rpc.V2beta.Event.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Event.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Event.t/0","doc":"","ref":"Sui.Rpc.V2beta.Event.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ExecuteTransactionRequest","doc":"","ref":"Sui.Rpc.V2beta.ExecuteTransactionRequest.html"},{"type":"function","title":"Sui.Rpc.V2beta.ExecuteTransactionRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ExecuteTransactionRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ExecuteTransactionRequest.t/0","doc":"","ref":"Sui.Rpc.V2beta.ExecuteTransactionRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ExecuteTransactionResponse","doc":"Response message for `NodeService.ExecuteTransaction`.","ref":"Sui.Rpc.V2beta.ExecuteTransactionResponse.html"},{"type":"function","title":"Sui.Rpc.V2beta.ExecuteTransactionResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ExecuteTransactionResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ExecuteTransactionResponse.t/0","doc":"","ref":"Sui.Rpc.V2beta.ExecuteTransactionResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ExecutedTransaction","doc":"","ref":"Sui.Rpc.V2beta.ExecutedTransaction.html"},{"type":"function","title":"Sui.Rpc.V2beta.ExecutedTransaction.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutedTransaction.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ExecutedTransaction.t/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutedTransaction.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ExecutionError","doc":"An error that can occur during the execution of a transaction.","ref":"Sui.Rpc.V2beta.ExecutionError.html"},{"type":"function","title":"Sui.Rpc.V2beta.ExecutionError.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionError.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ExecutionError.t/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionError.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ExecutionError.ExecutionErrorKind","doc":"","ref":"Sui.Rpc.V2beta.ExecutionError.ExecutionErrorKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.ExecutionError.ExecutionErrorKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionError.ExecutionErrorKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ExecutionError.ExecutionErrorKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionError.ExecutionErrorKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ExecutionStatus","doc":"The status of an executed transaction.","ref":"Sui.Rpc.V2beta.ExecutionStatus.html"},{"type":"function","title":"Sui.Rpc.V2beta.ExecutionStatus.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionStatus.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ExecutionStatus.t/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionStatus.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ExecutionTimeObservation","doc":"","ref":"Sui.Rpc.V2beta.ExecutionTimeObservation.html"},{"type":"function","title":"Sui.Rpc.V2beta.ExecutionTimeObservation.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionTimeObservation.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ExecutionTimeObservation.t/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionTimeObservation.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ExecutionTimeObservation.ExecutionTimeObservationKind","doc":"","ref":"Sui.Rpc.V2beta.ExecutionTimeObservation.ExecutionTimeObservationKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.ExecutionTimeObservation.ExecutionTimeObservationKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionTimeObservation.ExecutionTimeObservationKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ExecutionTimeObservation.ExecutionTimeObservationKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionTimeObservation.ExecutionTimeObservationKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ExecutionTimeObservations","doc":"","ref":"Sui.Rpc.V2beta.ExecutionTimeObservations.html"},{"type":"function","title":"Sui.Rpc.V2beta.ExecutionTimeObservations.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionTimeObservations.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ExecutionTimeObservations.t/0","doc":"","ref":"Sui.Rpc.V2beta.ExecutionTimeObservations.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.GasCostSummary","doc":"Summary of gas charges.","ref":"Sui.Rpc.V2beta.GasCostSummary.html"},{"type":"function","title":"Sui.Rpc.V2beta.GasCostSummary.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.GasCostSummary.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.GasCostSummary.t/0","doc":"","ref":"Sui.Rpc.V2beta.GasCostSummary.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.GasPayment","doc":"Payment information for executing a transaction.","ref":"Sui.Rpc.V2beta.GasPayment.html"},{"type":"function","title":"Sui.Rpc.V2beta.GasPayment.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.GasPayment.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.GasPayment.t/0","doc":"","ref":"Sui.Rpc.V2beta.GasPayment.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.GenesisTransaction","doc":"The genesis transaction.","ref":"Sui.Rpc.V2beta.GenesisTransaction.html"},{"type":"function","title":"Sui.Rpc.V2beta.GenesisTransaction.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.GenesisTransaction.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.GenesisTransaction.t/0","doc":"","ref":"Sui.Rpc.V2beta.GenesisTransaction.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.GetCheckpointRequest","doc":"","ref":"Sui.Rpc.V2beta.GetCheckpointRequest.html"},{"type":"function","title":"Sui.Rpc.V2beta.GetCheckpointRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.GetCheckpointRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.GetCheckpointRequest.t/0","doc":"","ref":"Sui.Rpc.V2beta.GetCheckpointRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.GetEpochRequest","doc":"message BatchGetCheckpointsRequest {\nrepeated GetCheckpointRequest requests = 1;\n\n// Mask specifying which fields to read.\n// If no mask is specified, defaults to `object_id,version,digest`.\noptional google.protobuf.FieldMask read_mask = 2;\n}\n\nmessage BatchGetCheckpointsResponse {\nrepeated Checkpoint checkpoints = 1;\n}","ref":"Sui.Rpc.V2beta.GetEpochRequest.html"},{"type":"function","title":"Sui.Rpc.V2beta.GetEpochRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.GetEpochRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.GetEpochRequest.t/0","doc":"","ref":"Sui.Rpc.V2beta.GetEpochRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.GetObjectRequest","doc":"","ref":"Sui.Rpc.V2beta.GetObjectRequest.html"},{"type":"function","title":"Sui.Rpc.V2beta.GetObjectRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.GetObjectRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.GetObjectRequest.t/0","doc":"","ref":"Sui.Rpc.V2beta.GetObjectRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.GetServiceInfoRequest","doc":"","ref":"Sui.Rpc.V2beta.GetServiceInfoRequest.html"},{"type":"function","title":"Sui.Rpc.V2beta.GetServiceInfoRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.GetServiceInfoRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.GetServiceInfoRequest.t/0","doc":"","ref":"Sui.Rpc.V2beta.GetServiceInfoRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.GetServiceInfoResponse","doc":"","ref":"Sui.Rpc.V2beta.GetServiceInfoResponse.html"},{"type":"function","title":"Sui.Rpc.V2beta.GetServiceInfoResponse.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.GetServiceInfoResponse.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.GetServiceInfoResponse.t/0","doc":"","ref":"Sui.Rpc.V2beta.GetServiceInfoResponse.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.GetTransactionRequest","doc":"","ref":"Sui.Rpc.V2beta.GetTransactionRequest.html"},{"type":"function","title":"Sui.Rpc.V2beta.GetTransactionRequest.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.GetTransactionRequest.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.GetTransactionRequest.t/0","doc":"","ref":"Sui.Rpc.V2beta.GetTransactionRequest.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Input","doc":"An input to a user transaction.","ref":"Sui.Rpc.V2beta.Input.html"},{"type":"function","title":"Sui.Rpc.V2beta.Input.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Input.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Input.t/0","doc":"","ref":"Sui.Rpc.V2beta.Input.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Input.InputKind","doc":"","ref":"Sui.Rpc.V2beta.Input.InputKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.Input.InputKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Input.InputKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Input.InputKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.Input.InputKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Jwk","doc":"A JSON web key.\n\nStruct that contains info for a JWK. A list of them for different kinds can\nbe retrieved from the JWK endpoint (for example,  ).\nThe JWK is used to verify the JWT token.","ref":"Sui.Rpc.V2beta.Jwk.html"},{"type":"function","title":"Sui.Rpc.V2beta.Jwk.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Jwk.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Jwk.t/0","doc":"","ref":"Sui.Rpc.V2beta.Jwk.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.JwkId","doc":"Key to uniquely identify a JWK.","ref":"Sui.Rpc.V2beta.JwkId.html"},{"type":"function","title":"Sui.Rpc.V2beta.JwkId.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.JwkId.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.JwkId.t/0","doc":"","ref":"Sui.Rpc.V2beta.JwkId.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.LedgerService.Service","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Service.html"},{"type":"function","title":"Sui.Rpc.V2beta.LedgerService.Service.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Service.html#descriptor/0"},{"type":"module","title":"Sui.Rpc.V2beta.LedgerService.Stub","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Stub.html"},{"type":"function","title":"Sui.Rpc.V2beta.LedgerService.Stub.batch_get_objects/3","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Stub.html#batch_get_objects/3"},{"type":"function","title":"Sui.Rpc.V2beta.LedgerService.Stub.batch_get_transactions/3","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Stub.html#batch_get_transactions/3"},{"type":"function","title":"Sui.Rpc.V2beta.LedgerService.Stub.get_checkpoint/3","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Stub.html#get_checkpoint/3"},{"type":"function","title":"Sui.Rpc.V2beta.LedgerService.Stub.get_epoch/3","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Stub.html#get_epoch/3"},{"type":"function","title":"Sui.Rpc.V2beta.LedgerService.Stub.get_object/3","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Stub.html#get_object/3"},{"type":"function","title":"Sui.Rpc.V2beta.LedgerService.Stub.get_service_info/3","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Stub.html#get_service_info/3"},{"type":"function","title":"Sui.Rpc.V2beta.LedgerService.Stub.get_transaction/3","doc":"","ref":"Sui.Rpc.V2beta.LedgerService.Stub.html#get_transaction/3"},{"type":"module","title":"Sui.Rpc.V2beta.MakeMoveVector","doc":"Command to build a Move vector out of a set of individual elements.","ref":"Sui.Rpc.V2beta.MakeMoveVector.html"},{"type":"function","title":"Sui.Rpc.V2beta.MakeMoveVector.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MakeMoveVector.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MakeMoveVector.t/0","doc":"","ref":"Sui.Rpc.V2beta.MakeMoveVector.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MergeCoins","doc":"Command to merge multiple coins of the same type into a single coin.","ref":"Sui.Rpc.V2beta.MergeCoins.html"},{"type":"function","title":"Sui.Rpc.V2beta.MergeCoins.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MergeCoins.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MergeCoins.t/0","doc":"","ref":"Sui.Rpc.V2beta.MergeCoins.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MoveCall","doc":"Command to call a Move function.\n\nFunctions that can be called by a `MoveCall` command are those that have a function signature\nthat is either `entry` or `public` (which don't have a reference return type).","ref":"Sui.Rpc.V2beta.MoveCall.html"},{"type":"function","title":"Sui.Rpc.V2beta.MoveCall.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MoveCall.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MoveCall.t/0","doc":"","ref":"Sui.Rpc.V2beta.MoveCall.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MoveLocation","doc":"Location in Move bytecode where an error occurred.","ref":"Sui.Rpc.V2beta.MoveLocation.html"},{"type":"function","title":"Sui.Rpc.V2beta.MoveLocation.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MoveLocation.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MoveLocation.t/0","doc":"","ref":"Sui.Rpc.V2beta.MoveLocation.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MoveModule","doc":"Module defined by a package.","ref":"Sui.Rpc.V2beta.MoveModule.html"},{"type":"function","title":"Sui.Rpc.V2beta.MoveModule.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MoveModule.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MoveModule.t/0","doc":"","ref":"Sui.Rpc.V2beta.MoveModule.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MoveTable","doc":"A message that represents a Move `0x2::table::Table` or `0x2::bag::Bag`","ref":"Sui.Rpc.V2beta.MoveTable.html"},{"type":"function","title":"Sui.Rpc.V2beta.MoveTable.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MoveTable.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MoveTable.t/0","doc":"","ref":"Sui.Rpc.V2beta.MoveTable.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MultisigAggregatedSignature","doc":"Aggregated signature from members of a multisig committee.","ref":"Sui.Rpc.V2beta.MultisigAggregatedSignature.html"},{"type":"function","title":"Sui.Rpc.V2beta.MultisigAggregatedSignature.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigAggregatedSignature.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MultisigAggregatedSignature.t/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigAggregatedSignature.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MultisigCommittee","doc":"A multisig committee.","ref":"Sui.Rpc.V2beta.MultisigCommittee.html"},{"type":"function","title":"Sui.Rpc.V2beta.MultisigCommittee.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigCommittee.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MultisigCommittee.t/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigCommittee.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MultisigMember","doc":"A member in a multisig committee.","ref":"Sui.Rpc.V2beta.MultisigMember.html"},{"type":"function","title":"Sui.Rpc.V2beta.MultisigMember.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigMember.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MultisigMember.t/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigMember.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MultisigMemberPublicKey","doc":"Set of valid public keys for multisig committee members.","ref":"Sui.Rpc.V2beta.MultisigMemberPublicKey.html"},{"type":"function","title":"Sui.Rpc.V2beta.MultisigMemberPublicKey.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigMemberPublicKey.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MultisigMemberPublicKey.t/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigMemberPublicKey.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.MultisigMemberSignature","doc":"A signature from a member of a multisig committee.","ref":"Sui.Rpc.V2beta.MultisigMemberSignature.html"},{"type":"function","title":"Sui.Rpc.V2beta.MultisigMemberSignature.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigMemberSignature.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.MultisigMemberSignature.t/0","doc":"","ref":"Sui.Rpc.V2beta.MultisigMemberSignature.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Object","doc":"An object on the Sui blockchain.","ref":"Sui.Rpc.V2beta.Object.html"},{"type":"function","title":"Sui.Rpc.V2beta.Object.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Object.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Object.t/0","doc":"","ref":"Sui.Rpc.V2beta.Object.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ObjectReference","doc":"Reference to an object.","ref":"Sui.Rpc.V2beta.ObjectReference.html"},{"type":"function","title":"Sui.Rpc.V2beta.ObjectReference.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ObjectReference.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ObjectReference.t/0","doc":"","ref":"Sui.Rpc.V2beta.ObjectReference.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Owner","doc":"Enum of different types of ownership for an object.","ref":"Sui.Rpc.V2beta.Owner.html"},{"type":"function","title":"Sui.Rpc.V2beta.Owner.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Owner.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Owner.t/0","doc":"","ref":"Sui.Rpc.V2beta.Owner.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Owner.OwnerKind","doc":"","ref":"Sui.Rpc.V2beta.Owner.OwnerKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.Owner.OwnerKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Owner.OwnerKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Owner.OwnerKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.Owner.OwnerKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.PackageUpgradeError","doc":"An error with upgrading a package.","ref":"Sui.Rpc.V2beta.PackageUpgradeError.html"},{"type":"function","title":"Sui.Rpc.V2beta.PackageUpgradeError.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.PackageUpgradeError.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.PackageUpgradeError.t/0","doc":"","ref":"Sui.Rpc.V2beta.PackageUpgradeError.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.PackageUpgradeError.PackageUpgradeErrorKind","doc":"","ref":"Sui.Rpc.V2beta.PackageUpgradeError.PackageUpgradeErrorKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.PackageUpgradeError.PackageUpgradeErrorKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.PackageUpgradeError.PackageUpgradeErrorKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.PackageUpgradeError.PackageUpgradeErrorKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.PackageUpgradeError.PackageUpgradeErrorKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.PasskeyAuthenticator","doc":"A passkey authenticator.\n\nSee\n[struct.PasskeyAuthenticator](https://mystenlabs.github.io/sui-rust-sdk/sui_sdk_types/struct.PasskeyAuthenticator.html#bcs)\nfor more information on the requirements on the shape of the\n`client_data_json` field.","ref":"Sui.Rpc.V2beta.PasskeyAuthenticator.html"},{"type":"function","title":"Sui.Rpc.V2beta.PasskeyAuthenticator.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.PasskeyAuthenticator.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.PasskeyAuthenticator.t/0","doc":"","ref":"Sui.Rpc.V2beta.PasskeyAuthenticator.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ProgrammableTransaction","doc":"A user transaction.\n\nContains a series of native commands and Move calls where the results of one command can be\nused in future commands.","ref":"Sui.Rpc.V2beta.ProgrammableTransaction.html"},{"type":"function","title":"Sui.Rpc.V2beta.ProgrammableTransaction.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ProgrammableTransaction.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ProgrammableTransaction.t/0","doc":"","ref":"Sui.Rpc.V2beta.ProgrammableTransaction.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ProtocolConfig","doc":"","ref":"Sui.Rpc.V2beta.ProtocolConfig.html"},{"type":"function","title":"Sui.Rpc.V2beta.ProtocolConfig.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ProtocolConfig.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ProtocolConfig.t/0","doc":"","ref":"Sui.Rpc.V2beta.ProtocolConfig.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ProtocolConfig.AttributesEntry","doc":"","ref":"Sui.Rpc.V2beta.ProtocolConfig.AttributesEntry.html"},{"type":"function","title":"Sui.Rpc.V2beta.ProtocolConfig.AttributesEntry.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ProtocolConfig.AttributesEntry.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ProtocolConfig.AttributesEntry.t/0","doc":"","ref":"Sui.Rpc.V2beta.ProtocolConfig.AttributesEntry.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ProtocolConfig.FeatureFlagsEntry","doc":"","ref":"Sui.Rpc.V2beta.ProtocolConfig.FeatureFlagsEntry.html"},{"type":"function","title":"Sui.Rpc.V2beta.ProtocolConfig.FeatureFlagsEntry.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ProtocolConfig.FeatureFlagsEntry.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ProtocolConfig.FeatureFlagsEntry.t/0","doc":"","ref":"Sui.Rpc.V2beta.ProtocolConfig.FeatureFlagsEntry.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Publish","doc":"Command to publish a new Move package.","ref":"Sui.Rpc.V2beta.Publish.html"},{"type":"function","title":"Sui.Rpc.V2beta.Publish.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Publish.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Publish.t/0","doc":"","ref":"Sui.Rpc.V2beta.Publish.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.RandomnessStateUpdate","doc":"Randomness update.","ref":"Sui.Rpc.V2beta.RandomnessStateUpdate.html"},{"type":"function","title":"Sui.Rpc.V2beta.RandomnessStateUpdate.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.RandomnessStateUpdate.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.RandomnessStateUpdate.t/0","doc":"","ref":"Sui.Rpc.V2beta.RandomnessStateUpdate.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.SignatureScheme","doc":"Flag use to disambiguate the signature schemes supported by Sui.\n\nNote: the enum values defined by this proto message exactly match their\nexpected BCS serialized values when serialized as a u8. See\n[enum.SignatureScheme](https://mystenlabs.github.io/sui-rust-sdk/sui_sdk_types/enum.SignatureScheme.html)\nfor more information about signature schemes.","ref":"Sui.Rpc.V2beta.SignatureScheme.html"},{"type":"function","title":"Sui.Rpc.V2beta.SignatureScheme.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.SignatureScheme.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.SignatureScheme.t/0","doc":"","ref":"Sui.Rpc.V2beta.SignatureScheme.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.SizeError","doc":"A size error.","ref":"Sui.Rpc.V2beta.SizeError.html"},{"type":"function","title":"Sui.Rpc.V2beta.SizeError.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.SizeError.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.SizeError.t/0","doc":"","ref":"Sui.Rpc.V2beta.SizeError.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.SplitCoins","doc":"Command to split a single coin object into multiple coins.","ref":"Sui.Rpc.V2beta.SplitCoins.html"},{"type":"function","title":"Sui.Rpc.V2beta.SplitCoins.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.SplitCoins.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.SplitCoins.t/0","doc":"","ref":"Sui.Rpc.V2beta.SplitCoins.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.StakeSubsidy","doc":"","ref":"Sui.Rpc.V2beta.StakeSubsidy.html"},{"type":"function","title":"Sui.Rpc.V2beta.StakeSubsidy.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.StakeSubsidy.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.StakeSubsidy.t/0","doc":"","ref":"Sui.Rpc.V2beta.StakeSubsidy.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.StakingPool","doc":"A staking pool embedded in each validator struct in the system state object.","ref":"Sui.Rpc.V2beta.StakingPool.html"},{"type":"function","title":"Sui.Rpc.V2beta.StakingPool.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.StakingPool.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.StakingPool.t/0","doc":"","ref":"Sui.Rpc.V2beta.StakingPool.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.StorageFund","doc":"Struct representing the onchain storage fund.","ref":"Sui.Rpc.V2beta.StorageFund.html"},{"type":"function","title":"Sui.Rpc.V2beta.StorageFund.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.StorageFund.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.StorageFund.t/0","doc":"","ref":"Sui.Rpc.V2beta.StorageFund.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.SystemPackage","doc":"System package.","ref":"Sui.Rpc.V2beta.SystemPackage.html"},{"type":"function","title":"Sui.Rpc.V2beta.SystemPackage.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.SystemPackage.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.SystemPackage.t/0","doc":"","ref":"Sui.Rpc.V2beta.SystemPackage.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.SystemParameters","doc":"","ref":"Sui.Rpc.V2beta.SystemParameters.html"},{"type":"function","title":"Sui.Rpc.V2beta.SystemParameters.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.SystemParameters.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.SystemParameters.t/0","doc":"","ref":"Sui.Rpc.V2beta.SystemParameters.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.SystemState","doc":"","ref":"Sui.Rpc.V2beta.SystemState.html"},{"type":"function","title":"Sui.Rpc.V2beta.SystemState.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.SystemState.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.SystemState.t/0","doc":"","ref":"Sui.Rpc.V2beta.SystemState.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Transaction","doc":"A transaction.","ref":"Sui.Rpc.V2beta.Transaction.html"},{"type":"function","title":"Sui.Rpc.V2beta.Transaction.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Transaction.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Transaction.t/0","doc":"","ref":"Sui.Rpc.V2beta.Transaction.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TransactionEffects","doc":"The effects of executing a transaction.","ref":"Sui.Rpc.V2beta.TransactionEffects.html"},{"type":"function","title":"Sui.Rpc.V2beta.TransactionEffects.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionEffects.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TransactionEffects.t/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionEffects.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TransactionEvents","doc":"Events emitted during the successful execution of a transaction.","ref":"Sui.Rpc.V2beta.TransactionEvents.html"},{"type":"function","title":"Sui.Rpc.V2beta.TransactionEvents.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionEvents.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TransactionEvents.t/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionEvents.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TransactionExecutionService.Service","doc":"","ref":"Sui.Rpc.V2beta.TransactionExecutionService.Service.html"},{"type":"function","title":"Sui.Rpc.V2beta.TransactionExecutionService.Service.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionExecutionService.Service.html#descriptor/0"},{"type":"module","title":"Sui.Rpc.V2beta.TransactionExecutionService.Stub","doc":"","ref":"Sui.Rpc.V2beta.TransactionExecutionService.Stub.html"},{"type":"function","title":"Sui.Rpc.V2beta.TransactionExecutionService.Stub.execute_transaction/3","doc":"","ref":"Sui.Rpc.V2beta.TransactionExecutionService.Stub.html#execute_transaction/3"},{"type":"module","title":"Sui.Rpc.V2beta.TransactionExpiration","doc":"A TTL for a transaction.","ref":"Sui.Rpc.V2beta.TransactionExpiration.html"},{"type":"function","title":"Sui.Rpc.V2beta.TransactionExpiration.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionExpiration.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TransactionExpiration.t/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionExpiration.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TransactionExpiration.TransactionExpirationKind","doc":"","ref":"Sui.Rpc.V2beta.TransactionExpiration.TransactionExpirationKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.TransactionExpiration.TransactionExpirationKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionExpiration.TransactionExpirationKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TransactionExpiration.TransactionExpirationKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionExpiration.TransactionExpirationKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TransactionFinality","doc":"Indicates the finality of the executed transaction.","ref":"Sui.Rpc.V2beta.TransactionFinality.html"},{"type":"function","title":"Sui.Rpc.V2beta.TransactionFinality.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionFinality.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TransactionFinality.t/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionFinality.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TransactionKind","doc":"Transaction type.","ref":"Sui.Rpc.V2beta.TransactionKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.TransactionKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TransactionKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.TransactionKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TransferObjects","doc":"Command to transfer ownership of a set of objects to an address.","ref":"Sui.Rpc.V2beta.TransferObjects.html"},{"type":"function","title":"Sui.Rpc.V2beta.TransferObjects.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TransferObjects.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TransferObjects.t/0","doc":"","ref":"Sui.Rpc.V2beta.TransferObjects.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TypeArgumentError","doc":"Type argument error.","ref":"Sui.Rpc.V2beta.TypeArgumentError.html"},{"type":"function","title":"Sui.Rpc.V2beta.TypeArgumentError.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TypeArgumentError.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TypeArgumentError.t/0","doc":"","ref":"Sui.Rpc.V2beta.TypeArgumentError.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TypeArgumentError.TypeArgumentErrorKind","doc":"","ref":"Sui.Rpc.V2beta.TypeArgumentError.TypeArgumentErrorKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.TypeArgumentError.TypeArgumentErrorKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TypeArgumentError.TypeArgumentErrorKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TypeArgumentError.TypeArgumentErrorKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.TypeArgumentError.TypeArgumentErrorKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.TypeOrigin","doc":"Identifies a struct and the module it was defined in.","ref":"Sui.Rpc.V2beta.TypeOrigin.html"},{"type":"function","title":"Sui.Rpc.V2beta.TypeOrigin.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.TypeOrigin.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.TypeOrigin.t/0","doc":"","ref":"Sui.Rpc.V2beta.TypeOrigin.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.UnchangedSharedObject","doc":"A shared object that wasn't changed during execution.","ref":"Sui.Rpc.V2beta.UnchangedSharedObject.html"},{"type":"function","title":"Sui.Rpc.V2beta.UnchangedSharedObject.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.UnchangedSharedObject.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.UnchangedSharedObject.t/0","doc":"","ref":"Sui.Rpc.V2beta.UnchangedSharedObject.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.UnchangedSharedObject.UnchangedSharedObjectKind","doc":"","ref":"Sui.Rpc.V2beta.UnchangedSharedObject.UnchangedSharedObjectKind.html"},{"type":"function","title":"Sui.Rpc.V2beta.UnchangedSharedObject.UnchangedSharedObjectKind.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.UnchangedSharedObject.UnchangedSharedObjectKind.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.UnchangedSharedObject.UnchangedSharedObjectKind.t/0","doc":"","ref":"Sui.Rpc.V2beta.UnchangedSharedObject.UnchangedSharedObjectKind.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Upgrade","doc":"Command to upgrade an already published package.","ref":"Sui.Rpc.V2beta.Upgrade.html"},{"type":"function","title":"Sui.Rpc.V2beta.Upgrade.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Upgrade.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Upgrade.t/0","doc":"","ref":"Sui.Rpc.V2beta.Upgrade.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.UpgradeInfo","doc":"/ Upgraded package info for the linkage table.","ref":"Sui.Rpc.V2beta.UpgradeInfo.html"},{"type":"function","title":"Sui.Rpc.V2beta.UpgradeInfo.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.UpgradeInfo.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.UpgradeInfo.t/0","doc":"","ref":"Sui.Rpc.V2beta.UpgradeInfo.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.UserSignature","doc":"A signature from a user.","ref":"Sui.Rpc.V2beta.UserSignature.html"},{"type":"function","title":"Sui.Rpc.V2beta.UserSignature.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.UserSignature.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.UserSignature.t/0","doc":"","ref":"Sui.Rpc.V2beta.UserSignature.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.Validator","doc":"Definition of a Validator in the system contracts\n\nNote: fields of ValidatorMetadata are flattened into this type","ref":"Sui.Rpc.V2beta.Validator.html"},{"type":"function","title":"Sui.Rpc.V2beta.Validator.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.Validator.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.Validator.t/0","doc":"","ref":"Sui.Rpc.V2beta.Validator.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ValidatorAggregatedSignature","doc":"/ An aggregated signature from multiple validators.","ref":"Sui.Rpc.V2beta.ValidatorAggregatedSignature.html"},{"type":"function","title":"Sui.Rpc.V2beta.ValidatorAggregatedSignature.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorAggregatedSignature.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ValidatorAggregatedSignature.t/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorAggregatedSignature.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ValidatorCommittee","doc":"The validator set for a particular epoch.","ref":"Sui.Rpc.V2beta.ValidatorCommittee.html"},{"type":"function","title":"Sui.Rpc.V2beta.ValidatorCommittee.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorCommittee.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ValidatorCommittee.t/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorCommittee.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ValidatorCommitteeMember","doc":"A member of a validator committee.","ref":"Sui.Rpc.V2beta.ValidatorCommitteeMember.html"},{"type":"function","title":"Sui.Rpc.V2beta.ValidatorCommitteeMember.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorCommitteeMember.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ValidatorCommitteeMember.t/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorCommitteeMember.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ValidatorExecutionTimeObservation","doc":"","ref":"Sui.Rpc.V2beta.ValidatorExecutionTimeObservation.html"},{"type":"function","title":"Sui.Rpc.V2beta.ValidatorExecutionTimeObservation.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorExecutionTimeObservation.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ValidatorExecutionTimeObservation.t/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorExecutionTimeObservation.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ValidatorReportRecord","doc":"","ref":"Sui.Rpc.V2beta.ValidatorReportRecord.html"},{"type":"function","title":"Sui.Rpc.V2beta.ValidatorReportRecord.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorReportRecord.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ValidatorReportRecord.t/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorReportRecord.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ValidatorSet","doc":"","ref":"Sui.Rpc.V2beta.ValidatorSet.html"},{"type":"function","title":"Sui.Rpc.V2beta.ValidatorSet.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorSet.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ValidatorSet.t/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorSet.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ValidatorSet.AtRiskValidatorsEntry","doc":"","ref":"Sui.Rpc.V2beta.ValidatorSet.AtRiskValidatorsEntry.html"},{"type":"function","title":"Sui.Rpc.V2beta.ValidatorSet.AtRiskValidatorsEntry.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorSet.AtRiskValidatorsEntry.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ValidatorSet.AtRiskValidatorsEntry.t/0","doc":"","ref":"Sui.Rpc.V2beta.ValidatorSet.AtRiskValidatorsEntry.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.VersionAssignment","doc":"Object version assignment from consensus.","ref":"Sui.Rpc.V2beta.VersionAssignment.html"},{"type":"function","title":"Sui.Rpc.V2beta.VersionAssignment.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.VersionAssignment.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.VersionAssignment.t/0","doc":"","ref":"Sui.Rpc.V2beta.VersionAssignment.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ZkLoginAuthenticator","doc":"A zklogin authenticator.","ref":"Sui.Rpc.V2beta.ZkLoginAuthenticator.html"},{"type":"function","title":"Sui.Rpc.V2beta.ZkLoginAuthenticator.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginAuthenticator.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ZkLoginAuthenticator.t/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginAuthenticator.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ZkLoginClaim","doc":"A claim of the iss in a zklogin proof.","ref":"Sui.Rpc.V2beta.ZkLoginClaim.html"},{"type":"function","title":"Sui.Rpc.V2beta.ZkLoginClaim.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginClaim.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ZkLoginClaim.t/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginClaim.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ZkLoginInputs","doc":"A zklogin groth16 proof and the required inputs to perform proof verification.","ref":"Sui.Rpc.V2beta.ZkLoginInputs.html"},{"type":"function","title":"Sui.Rpc.V2beta.ZkLoginInputs.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginInputs.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ZkLoginInputs.t/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginInputs.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ZkLoginProof","doc":"A zklogin groth16 proof.","ref":"Sui.Rpc.V2beta.ZkLoginProof.html"},{"type":"function","title":"Sui.Rpc.V2beta.ZkLoginProof.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginProof.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ZkLoginProof.t/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginProof.html#t:t/0"},{"type":"module","title":"Sui.Rpc.V2beta.ZkLoginPublicIdentifier","doc":"Public key equivalent for zklogin authenticators.","ref":"Sui.Rpc.V2beta.ZkLoginPublicIdentifier.html"},{"type":"function","title":"Sui.Rpc.V2beta.ZkLoginPublicIdentifier.descriptor/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginPublicIdentifier.html#descriptor/0"},{"type":"type","title":"Sui.Rpc.V2beta.ZkLoginPublicIdentifier.t/0","doc":"","ref":"Sui.Rpc.V2beta.ZkLoginPublicIdentifier.html#t:t/0"},{"type":"extras","title":"Guide","doc":"# ExSui\n\nExSui is a comprehensive Elixir library that provides a high-performance, type-safe interface for interacting with the \n[Sui](https://sui.io/) blockchain through its native [gRPC API](https://docs.sui.io/concepts/grpc-overview). This library is a work in progress.\n\n[Sui](https://sui.io/) is a Layer 1 blockchain designed for near-instant, low-cost transactions with parallel processing and optimized scalability, making it ideal for DeFi, NFTs, and gaming. Sui uses [Move](https://sui.io/move), a smart contract language designed for safety and efficiency. Unlike traditional smart contract languages like Solidity, Move is built with security in mind, minimizing common vulnerabilities such as reentrancy attacks and ensuring better resource management.","ref":"readme.html"},{"type":"extras","title":"Getting Started - Guide","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `ex_sui` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_sui, git: \"https://github.com/briankariuki/ex_sui.git\"}\n  ]\nend\n```","ref":"readme.html#getting-started"},{"type":"extras","title":"Usage - Guide","doc":"In iex you can access base methods in the `ExSui` module. For example,\n\nGetting a transaction's details\n\n```elixir\niex> transaction = %Sui.Rpc.V2beta.GetTransactionRequest{digest: \"sp9rx3yRjDxfTbmA4xoU5FDw5233Y1S3pVaRdg8UzyJ\", read_mask: %{paths: [\"digest\", \"signatures\", \"events\", \"transaction\"]}}\n\niex> ExSui.get_transaction(transaction)\n{:ok,\n %Sui.Rpc.V2beta.ExecutedTransaction{\n   digest: \"sp9rx3yRjDxfTbmA4xoU5FDw5233Y1S3pVaRdg8UzyJ\",\n   transaction: %Sui.Rpc.V2beta.Transaction{\n     bcs: %Sui.Rpc.V2beta.Bcs{\n       name: \"TransactionData\",\n       value: <<0, 0, 5, ...>>,\n       __unknown_fields__: []\n     },\n     digest: \"sp9rx3yRjDxfTbmA4xoU5FDw5233Y1S3pVaRdg8UzyJ\",\n     version: 1,\n     kind: %Sui.Rpc.V2beta.TransactionKind{\n       kind: {:programmable_transaction, ...},\n       __unknown_fields__: []\n     },\n     sender: \"0x7afd2906726498dd5395dc26ec563ce22aa502200c0fa3a69aa2d30f2b382027\",\n     gas_payment: %Sui.Rpc.V2beta.GasPayment{...},\n     ...\n   },\n   signatures: [\n     %Sui.Rpc.V2beta.UserSignature{\n       bcs: %Sui.Rpc.V2beta.Bcs{\n         name: \"UserSignatureBytes\",\n         value: <<5, ...>>,\n         __unknown_fields__: []\n       },\n       scheme: :ZKLOGIN,\n       signature: nil,\n       public_key: nil,\n       ...\n     }\n   ],\n   effects: nil,\n   events: %Sui.Rpc.V2beta.TransactionEvents{\n     bcs: %Sui.Rpc.V2beta.Bcs{name: \"TransactionEvents\", value: <<...>>, ...},\n     digest: \"8yyjrqPFKX7WVMFkJdVCAavWaZKDmp1k6sGeBsh9db81\",\n     events: [...],\n     ...\n   },\n   checkpoint: nil,\n   timestamp: nil,\n   balance_changes: [],\n   ...\n }}\n\n```\n\nGetting the current checkpoint details\n```elixir\niex> request = %Sui.Rpc.V2beta.GetCheckpointRequest{read_mask: %{paths: [\"summary\", \"digest\", \"sequence_number\"]}}\niex> ExSui.get_checkpoint(request)\n{:ok,\n %Sui.Rpc.V2beta.Checkpoint{\n   sequence_number: 213034443,\n   digest: \"Bf1DgoFuknnAjd5SC1h3Ve6aAhGxvmpuh1gGDAakWGUk\",\n   summary: %Sui.Rpc.V2beta.CheckpointSummary{\n     bcs: %Sui.Rpc.V2beta.Bcs{\n       name: \"CheckpointSummary\",\n       value: <<11, 3, 0, 0, 0, 0, 0, 0, 203, 165, 178, 12, 0, 0, 0, 0, 62, 47,\n         10, 156, 0, 0, 0, 0, 32, 78, 75, 57, 28, 43, 235, 46, 138, 117, 73, 59,\n         122, 171, 84, 119, 79, 93, ...>>,\n       __unknown_fields__: []\n     },\n     digest: \"Bf1DgoFuknnAjd5SC1h3Ve6aAhGxvmpuh1gGDAakWGUk\",\n     epoch: 779,\n     sequence_number: 213034443,\n     total_network_transactions: 2617913150,\n     content_digest: \"6GdL2k3QWfN4eicvgTEo55FfMH3QK1TRoLDoRfyN45KE\",\n     previous_digest: \"Aqkj4bSHRoT83MjjcsxSvpMqf9qZc3dFq8xAVFekad6j\",\n     epoch_rolling_gas_cost_summary: %Sui.Rpc.V2beta.GasCostSummary{\n       computation_cost: 1115817221792,\n       storage_cost: 9846684282800,\n       storage_rebate: 8752065218424,\n       non_refundable_storage_fee: 88404699176,\n       __unknown_fields__: []\n     },\n     timestamp: %Google.Protobuf.Timestamp{\n       seconds: 1751141311,\n       nanos: 898000000,\n       __unknown_fields__: []\n     },\n     commitments: [],\n     end_of_epoch_data: nil,\n     version_specific_data: <<0, 1, 138, 102, 2, 0, 0, 0, 0, 0>>,\n     __unknown_fields__: []\n   },\n   signature: nil,\n   contents: nil,\n   transactions: [],\n   __unknown_fields__: []\n }}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Contributing - Guide","doc":"[Download](https://github.com/protocolbuffers/protobuf?tab=readme-ov-file#protobuf-compiler-installation) and install the protocol buffer compiler (protoc).\n\nMacOS users can install it through Homebrew by running the following command: \n```\nbrew install protobuf\n```\nOther platforms e.g. windows, linux can be installed by following the steps [here](https://github.com/protocolbuffers/protobuf?tab=readme-ov-file#protobuf-compiler-installation).\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#contributing"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2025 Brian Kariuki\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}